@@ -3,14 +3,32 @@
 use std::error::Error;
 use std::fmt;
 
+/// List API data type
 #[derive(Debug, serde::Deserialize, Default, Clone)]
 pub struct ListData<T> {
+    pub current_page: Option<u8>,
     pub count: usize,
     pub next: Option<String>,
     pub previous: Option<String>,
     pub results: Vec<T>,
 }
 
+impl<T> ListData<T> {
+    pub fn has_next(&self) -> bool {
+        match self.next {
+            Some(_) => true,
+            _ => false,
+        }
+    }
+
+    pub fn has_prev(&self) -> bool {
+        match self.previous {
+            Some(_) => true,
+            _ => false,
+        }
+    }
+}
+
 impl<T> IntoIterator for ListData<T> {
     type Item = T;
     type IntoIter = std::vec::IntoIter<Self::Item>;
@@ -20,6 +38,7 @@ impl<T> IntoIterator for ListData<T> {
     }
 }
 
+/// Custom error type for return failed response
 #[derive(Debug)]
 pub struct RequestFailed(pub reqwest::blocking::Response);
 
